==> mise-2026.1.8.tar.gz: mise-2026.1.8/src/config/env_directive/module.rs <==
use crate::Result;
use crate::config::env_directive::EnvResults;
use crate::dirs;
use crate::plugins::vfox_plugin::VfoxPlugin;
use heck::ToKebabCase;
use std::path::PathBuf;
use toml::Value;

impl EnvResults {
    pub async fn module(
        r: &mut EnvResults,
        source: PathBuf,
        name: String,
        value: &Value,
        redact: bool,
    ) -> Result<()> {
        let path = dirs::PLUGINS.join(name.to_kebab_case());
        let plugin = VfoxPlugin::new(name, path.clone());
        if let Some(response) = plugin.mise_env(value).await? {
            // Track cacheability
            if !response.cacheable {
                r.has_uncacheable = true;
            }

            // Add plugin directory to watch files for cache invalidation
            // This ensures cache invalidates when plugin is updated
            r.watch_files.push(path);

            // Add watch files for cache invalidation
            // Absolutize relative paths to ensure consistent cache validation
            // regardless of which directory mise is run from
            let cwd = std::env::current_dir().unwrap_or_default();
            for watch_file in response.watch_files {
                if watch_file.is_absolute() {
                    r.watch_files.push(watch_file);
                } else {
                    r.watch_files.push(cwd.join(watch_file));
                }
            }

            // Add env vars
            for (k, v) in response.env {
                if redact {
                    r.redactions.push(k.clone());
                }
                r.env.insert(k, (v, source.clone()));
            }
        }
        if let Some(path) = plugin.mise_path(value).await? {
            for p in path {
                r.env_paths.push(p.into());
            }
        }
        Ok(())
    }
}

==> mise-2026.2.0.tar.gz: mise-2026.2.0/src/config/env_directive/module.rs <==
use crate::Result;
use crate::config::env_directive::EnvResults;
use crate::dirs;
use crate::plugins::vfox_plugin::VfoxPlugin;
use heck::ToKebabCase;
use indexmap::IndexMap;
use std::path::PathBuf;
use toml::Value;

impl EnvResults {
    pub async fn module(
        r: &mut EnvResults,
        source: PathBuf,
        name: String,
        value: &Value,
        redact: bool,
        env: IndexMap<String, String>,
    ) -> Result<()> {
        let path = dirs::PLUGINS.join(name.to_kebab_case());
        let plugin = VfoxPlugin::new(name, path.clone());
        if let Some(response) = plugin.mise_env(value, &env).await? {
            // Track cacheability
            if !response.cacheable {
                r.has_uncacheable = true;
            }

            // Add plugin directory to watch files for cache invalidation
            // This ensures cache invalidates when plugin is updated
            r.watch_files.push(path);

            // Add watch files for cache invalidation
            // Absolutize relative paths to ensure consistent cache validation
            // regardless of which directory mise is run from
            let cwd = std::env::current_dir().unwrap_or_default();
            for watch_file in response.watch_files {
                if watch_file.is_absolute() {
                    r.watch_files.push(watch_file);
                } else {
                    r.watch_files.push(cwd.join(watch_file));
                }
            }

            // Add env vars
            for (k, v) in response.env {
                if redact {
                    r.redactions.push(k.clone());
                }
                r.env.insert(k, (v, source.clone()));
            }
        }
        if let Some(path) = plugin.mise_path(value, &env).await? {
            for p in path {
                r.env_paths.push(p.into());
            }
        }
        Ok(())
    }
}
